pub(crate) fn build_range_cache_key(
stream_ctx: &StreamContext,
part_range: &PartitionRange,
) -> Option<RangeScanCacheKey>Expand description
Builds a cache key for the given partition range if it is eligible for caching.
pub(crate) fn build_range_cache_key(
stream_ctx: &StreamContext,
part_range: &PartitionRange,
) -> Option<RangeScanCacheKey>Builds a cache key for the given partition range if it is eligible for caching.