pk_values_ptr_eq

Function pk_values_ptr_eq 

fn pk_values_ptr_eq(
    a: &DictionaryArray<UInt32Type>,
    b: &DictionaryArray<UInt32Type>,
) -> bool
Returns true if two primary key dictionary arrays share the same underlying values buffers by pointer comparison.

The primary key column is always DictionaryArray<UInt32Type> with Binary values.